﻿using System;
using System.Windows.Data;

namespace BC3Technologies.Common.Mobile.Converters
{
	public class ByteStringConverter : IValueConverter
	{
		public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			var numOfBytes = System.Convert.ToInt64(value);
			var precision = parameter != null ? System.Convert.ToInt16(parameter) : 2;
			if (numOfBytes <= 0 && precision < 0)
			{
				return string.Empty;
			}

			precision = Math.Max(0, precision);
			if (numOfBytes >= (int)ByteUnit.GB)
			{
				return string.Concat(Math.Round(numOfBytes / (double)ByteUnit.GB, precision), "GB");
			}
			else if (numOfBytes >= (int)ByteUnit.MB)
			{
				return string.Concat(Math.Round(numOfBytes / (double)ByteUnit.MB, precision), "MB");
			}
			else if (numOfBytes >= (int)ByteUnit.KB)
			{
				return string.Concat(Math.Round(numOfBytes / (double)ByteUnit.KB, precision), "KB");
			}

			return string.Concat(numOfBytes, "B");
		}

		public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			var stringVal = (string)value;
			var pos = stringVal.IndexOf("GB", StringComparison.OrdinalIgnoreCase);
			if (pos != -1)
			{
				return long.Parse(stringVal.Substring(0, pos)) * (int)ByteUnit.GB;
			}
			else
			{
				pos = stringVal.IndexOf("MB", StringComparison.OrdinalIgnoreCase);
				if (pos != -1)
				{
					return long.Parse(stringVal.Substring(0, pos)) * (int)ByteUnit.MB;
				}
				else
				{
					pos = stringVal.IndexOf("KB", StringComparison.OrdinalIgnoreCase);
					if (pos != -1)
					{
						return long.Parse(stringVal.Substring(0, pos)) * (int)ByteUnit.KB;
					}

					return long.Parse(stringVal.Substring(0, stringVal.Length - 1));
				}
			}
		}
	}
}
